==> org.eclipse.riena.tests.source_2.0.0.v20100615_2_0_0.jar: org/eclipse/riena/core/cache/LRUHashMapTest.java <==
/*******************************************************************************
 * Copyright (c) 2007, 2010 compeople AG and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    compeople AG - initial API and implementation
 *******************************************************************************/
package org.eclipse.riena.core.cache;

import java.util.Map;

import org.eclipse.riena.internal.core.test.RienaTestCase;
import org.eclipse.riena.internal.core.test.collect.NonUITestCase;

/**
 * Tests the LRUHashMap class.
 * 
 */
@NonUITestCase
public class LRUHashMapTest extends RienaTestCase {

	private Map<String, Integer> lru = LRUHashMap.createLRUHashMap(3);

	public void testInstantiate() {
		assertEquals(0, lru.size());
	}

	public void testToTheLimit() {
		put(1, 2, 3);
		assertContains(1, 2, 3);
		assertEquals(3, lru.size());
		put(4);
		assertEquals(3, lru.size());
		assertContains(2, 3, 4);
	}

	public void testOverTheLimitAndTouchInTheMiddle() {
		put(1, 2, 3);
		assertContains(1, 2, 3);
		assertEquals(3, lru.size());
		put(4);
		assertEquals(3, lru.size());
		assertContains(2, 3, 4);

		assertContains(2);
		put(5);
		assertContains(2, 4, 5);
	}

	private void put(int... kvs) {
		for (int i : kvs) {
			lru.put(Integer.toString(i), i);
		}
	}

	private void assertContains(int... kvs) {
		for (int i : kvs) {
			assertEquals((Integer) i, lru.get(Integer.toString(i)));
		}
	}
}

==> org.eclipse.riena.tests.source_3.0.0.v20110614_3_0_0_0.jar: org/eclipse/riena/core/cache/LRUHashMapTest.java <==
/*******************************************************************************
 * Copyright (c) 2007, 2011 compeople AG and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    compeople AG - initial API and implementation
 *******************************************************************************/
package org.eclipse.riena.core.cache;

import java.util.Map;

import org.eclipse.riena.internal.core.test.RienaTestCase;
import org.eclipse.riena.internal.core.test.collect.NonUITestCase;

/**
 * Tests the LRUHashMap class.
 * 
 */
@NonUITestCase
public class LRUHashMapTest extends RienaTestCase {

	private final Map<String, Integer> lru = LRUHashMap.createLRUHashMap(3);

	public void testInstantiate() {
		assertEquals(0, lru.size());
	}

	public void testToTheLimit() {
		put(1, 2, 3);
		assertContains(1, 2, 3);
		assertEquals(3, lru.size());
		put(4);
		assertEquals(3, lru.size());
		assertContains(2, 3, 4);
	}

	public void testOverTheLimitAndTouchInTheMiddle() {
		put(1, 2, 3);
		assertContains(1, 2, 3);
		assertEquals(3, lru.size());
		put(4);
		assertEquals(3, lru.size());
		assertContains(2, 3, 4);

		assertContains(2);
		put(5);
		assertContains(2, 4, 5);
	}

	private void put(final int... kvs) {
		for (final int i : kvs) {
			lru.put(Integer.toString(i), i);
		}
	}

	private void assertContains(final int... kvs) {
		for (final int i : kvs) {
			assertEquals((Integer) i, lru.get(Integer.toString(i)));
		}
	}
}
